SystemOrganization addCategory: #'ICU-Tests-Core'!

TestCase subclass: #ICUCalendarTest
	instanceVariableNames: 'calendar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ICUCalendarTest methodsFor: 'running' stamp: 'JanVanDeSandt 3/2/2012 14:46'!
tearDown

	calendar notNil
		ifTrue: [ calendar close ]! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:53'!
testDutchCalendar

	calendar := ICUCalendar newWithLocale: 'nl' timeZone: 'Europe/Amsterdam'.

	self assert: calendar zoneOffset > 0.
	self assert: calendar dstOffset notNil! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:47'!
testGetAllTimeZones

	| timeZones |
	
	timeZones := ICUCalendar allTimeZones.
	
	self assert: (timeZones includes: 'Europe/Amsterdam')! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:51'!
testGetDayOfYear

	calendar := ICUCalendar new.

	self assert: calendar dayOfYear < 370! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:52'!
testGetDefaultTimeZone

	| timeZone |
	
	timeZone := ICUCalendar defaultTimeZone.
	
	self assert: timeZone isString! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:51'!
testGetOffsets

	calendar := ICUCalendar new.

	self assert: calendar zoneOffset notNil.
	self assert: calendar dstOffset notNil! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/30/2012 13:54'!
testMillis


	calendar := ICUCalendar new.
	self assert: calendar millis >= 0.
	
	calendar millis: 100000.
	self assert: calendar millis = 100000.
	
	calendar clear.
	self assert: calendar millis <= 0.
! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/29/2012 23:17'!
testSetDate


	calendar := ICUCalendar new.
	calendar clear.
	calendar setDate: 2012 with: 8 with: 21.
	
	self assert: calendar dayOfYear = 265.
	self assert: calendar dayOfMonth = 21.
	self assert: calendar year = 2012.
	self assert: calendar weekOfYear = 38.

	self assert: calendar hourOfDay = 0.
	self assert: calendar minute = 0.
! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/29/2012 10:09'!
testSetDateTime


	calendar := ICUCalendar new.
	calendar setDateTime: 2012 with: 8 with: 21 with: 17 with: 55 with: 54.
	
	self assert: calendar dayOfYear = 265.
	self assert: calendar dayOfMonth = 21.
	self assert: calendar year = 2012.
	self assert: calendar weekOfYear = 38.
	self assert: calendar hour = 5.
	self assert: calendar hourOfDay = 17.
	self assert: calendar minute = 55.
	self assert: calendar second = 54.
	
	calendar milliSecond: 333.
	self assert: calendar milliSecond = 333.
	
	calendar hourOfDay: 9.
	self assert: calendar hourOfDay = 9.! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'jvds 6/13/2011 14:29'!
testStability

	100 timesRepeat: [ self testGetAllTimeZones ] ! !

TestCase subclass: #ICUConverterTest
	instanceVariableNames: 'converter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ICUConverterTest methodsFor: 'utility' stamp: 'jvds 2/26/2012 22:21'!
asString: aCollectionOfIntegers

	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!ICUConverterTest methodsFor: 'utility' stamp: 'jvds 2/26/2012 14:50'!
specialCharsString

	^ self asString: #(83 233 228 115 238 100 233)! !

!ICUConverterTest methodsFor: 'utility' stamp: 'JanVanDeSandt 3/9/2012 14:55'!
specialCharsWideString

	^ WideString
		with: $S 
		with: 233 asCharacter
		with: 228 asCharacter
		with: Character euro! !

!ICUConverterTest methodsFor: 'running' stamp: 'jvds 2/26/2012 14:14'!
tearDown

	converter notNil
		ifTrue: [
			converter close.
			converter := nil ]! !

!ICUConverterTest methodsFor: 'tests' stamp: 'jvds 2/26/2012 14:06'!
testAllNames

	| names |
	
	names := ICUConverter allNames.
	
	self assert: (names includes: 'UTF-8')! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 14:12'!
testByteStringAsUTF16

	| output |

	output := ICUConverter byteStringAsUTF16: self specialCharsString.
	self assert: output = #[83 0 233 0 228 0 115 0 238 0 100 0 233 0]! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 16:31'!
testByteStringAsUTF8

	| output |

	output := ICUConverter byteStringAsUTF8: self specialCharsString.
	self assert: output = #[ 83 195 169 195 164 115 195 174 100 195 169 ]! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 15:15'!
testByteStringFromUTF16

	| output |

	output := ICUConverter byteStringFromUTF16: #[83 0 233 0 228 0 115 0 238 0 100 0 233 0].
	self assert: output = self specialCharsString.! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/4/2012 15:15'!
testByteStringFromUTF8

	| output |

	output := ICUConverter byteStringFromUTF8: #[ 83 195 169 195 164 115 195 174 100 195 169 ].
	self assert: output = self specialCharsString.! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/4/2012 14:15'!
testGetDefaultName

	| name |
	
	name := ICUConverter defaultName.
	
	self assert: (name isString and: [ name notEmpty ])! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/4/2012 15:25'!
testLatin1ToUTF

	| text bytes length |

	converter := ICUConverter openLatin1.
	
	text := self specialCharsString.
	bytes := ByteArray new: 200.

	length := converter toType: ICUConverter converterTypeUTF8 source: text destination: bytes.
	self assert: (bytes copyFrom: 1 to: length) = #[ 83 195 169 195 164 115 195 174 100 195 169 ].	
	
	length := converter toType: ICUConverter converterTypeUTF16BE source: text destination: bytes.
	self assert: (bytes copyFrom: 1 to: length) = #[ 0 83 0 233 0 228 0 115 0 238 0 100 0 233 ].

	length := converter toType: ICUConverter converterTypeUTF16LE source: text destination: bytes.
	self assert: (bytes copyFrom: 1 to: length) = #[ 83 0 233 0 228 0 115 0 238 0 100 0 233 0 ].

	length := converter toType: ICUConverter converterTypeUTF32 source: text destination: bytes.
	self assert: length = 32.
	
	length := converter toType: ICUConverter converterTypeUTF32BE source: text destination: bytes.
	self assert: length = 28.
	self assert: (bytes copyFrom: 1 to: 4) = #[ 0 0 0 83 ].
	
	length := converter toType: ICUConverter converterTypeUTF32LE source: text destination: bytes.
	self assert: length = 28.
	self assert: (bytes copyFrom: 1 to: 4) = #[ 83 0 0 0 ].
! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/25/2012 20:49'!
testOpenUTF8Converter

	| text utf16 |

	converter := ICUConverter openUTF8.
	"self assert: converter name = 'UTF-8'."
	self assert: converter type = ICUConverter converterTypeUTF8.
	self deny: converter isAmbiguous.
	
	text := 'Smalltalk'.
	utf16 := converter toUTF16: text.
	
	self assert: utf16 size = (text size * 2).
	self assert: (converter fromUTF16: utf16) asString = text! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 14:47'!
testUTF8ConverterWithSpecialChars

	| text utf16 |

	converter := ICUConverter openISO_8859_1.
	
	text := self specialCharsString.
	utf16 := converter toUTF16: text.
	
	self assert: utf16 byteSize = (text size * 2).
	self assert: (converter fromUTF16: utf16) asString = text! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 15:08'!
testWideStringAsUTF16

	| output |

	output := ICUConverter wideStringAsUTF16: self specialCharsString asWideString.
	self assert: output = #[ 83 0 233 0 228 0 115 0 238 0 100 0 233 0].
	
	output := ICUConverter wideStringAsUTF16: self specialCharsWideString.
	self assert: output = #[ 83 0 233 0 228 0 172 32 ]
	
	
! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 15:06'!
testWideStringAsUTF8

	| output |

	output := ICUConverter wideStringAsUTF8: self specialCharsString asWideString.
	self assert: output = #[ 83 195 169 195 164 115 195 174 100 195 169 ].
	
	output := ICUConverter wideStringAsUTF8: self specialCharsWideString.
	self assert: output = #[ 83 195 169 195 164 226 130 172 ]
	
	
! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 15:41'!
testWideStringFromUTF16

	| output |

	output := ICUConverter wideStringFromUTF16: #[ 83 0 233 0 228 0 115 0 238 0 100 0 233 0].
	self assert: output = self specialCharsString asWideString.
	
	output := ICUConverter wideStringFromUTF16: #[ 83 0 233 0 228 0 172 32 ].
	self assert: output = self specialCharsWideString ! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 15:36'!
testWideStringFromUTF8

	| output |

	output := ICUConverter wideStringFromUTF8: #[ 83 195 169 195 164 115 195 174 100 195 169 ].
	self assert: output = self specialCharsString asWideString.
	
	output := ICUConverter wideStringFromUTF8: #[ 83 195 169 195 164 226 130 172 ].
	self assert: output = self specialCharsWideString ! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/4/2012 15:50'!
testWordArrayBuffer

	| text buffer byteLength |

	converter := ICUConverter openLatin1.
	
	text := self specialCharsString.

	buffer := "WordArray"ByteArray new: 200.
	byteLength := converter toType: ICUConverter converterTypeUTF32 source: text destination: buffer.
	
	byteLength := converter toType: ICUConverter converterTypeUTF32BE source: text destination: buffer.
	
	byteLength := converter toType: ICUConverter converterTypeUTF32LE source: text destination: buffer.! !

TestCase subclass: #ICUDateFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ICUDateFormatTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/29/2012 14:19'!
testDefaultFormat

	| date result |
	
	date := ICUCalendar new millis.
	result := ICUDateFormat new format: date.

	self assert: result isString.
! !

!ICUDateFormatTest methodsFor: 'tests' stamp: 'JanVanDeSandt 11/30/2012 14:03'!
testFullFormat

	| date result |
	
	date := ICUCalendar new millis.

	result := ICUDateFormat fullTimeFullDate format: date.
	self assert: result isString.
	
	result := (ICUDateFormat fullTimeFullDate: 'nl') format: date.
	self assert: result isString.
	
	result := (ICUDateFormat fullTimeFullDate: 'nl' timeZoneId: 'Europe/Amsterdam') format: date.
	self assert: result isString.

	result := ICUDateFormat fullTime format: date.
	result := ICUDateFormat fullDate format: date.
! !

!ICUDateFormatTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/29/2012 22:47'!
testLenient

	| formatter |
	
	formatter := ICUDateFormat new.
	
	formatter lenient: false.
	self assert: formatter isLenient not.
	
	formatter lenient: true.
	self assert: formatter isLenient ! !

!ICUDateFormatTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/29/2012 15:03'!
testParseFullFormat

	| date formatter result |
	
	date := ICUCalendar new millis.
	formatter := ICUDateFormat fullTimeFullDate.

	result := formatter format: date.
	self assert: result isString.

	result := formatter parse: result.
	self assert: (date - result) abs < 1000! !

!ICUDateFormatTest methodsFor: 'tests' stamp: 'JanVanDeSandt 11/30/2012 14:54'!
testPattern

	| format result |
	
	format := ICUDateFormat locale: 'nl' timeZoneId: ' CES' pattern: 'YYYY-MM-dd'.

	self assert: (format formatDate: (Date newDay: 10 month: 5 year: 2011 )) = '2011-05-10'! !

TestCase subclass: #ICULocaleTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ICULocaleTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/25/2012 21:30'!
testAllAvailable

	self assert: (ICULocale allAvailable includes: 'nl_NL')! !

!ICULocaleTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/9/2012 11:21'!
testDefaultLocaleName

	self assert: ICULocale defaultLocaleName isString! !

!ICULocaleTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/25/2012 21:28'!
testDisplayName

	self assert: 'Nederlands' = (ICULocale displayName: 'nl' in: 'nl').
	self assert: 'Duits' = (ICULocale displayName: 'de' in: 'nl').! !

!ICULocaleTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/25/2012 21:31'!
testISOCountres

	self assert: (ICULocale isoCountries includes: 'NL')! !

!ICULocaleTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/25/2012 21:31'!
testISOLanguages

	self assert: (ICULocale isoLanguages includes: 'nl')! !

!ICULocaleTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/25/2012 21:25'!
testSetDefault

	| locale |
	
	locale := ICULocale defaultLocaleName.
	
	ICULocale defaultLocaleName: 'nl_NL'.
	self assert: 'nl_NL' = ICULocale defaultLocaleName.
	
	ICULocale defaultLocaleName: locale.
	self assert: locale = ICULocale defaultLocaleName! !

TestCase subclass: #ICURegularExpressionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ICURegularExpressionTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/31/2012 21:24'!
testFInd

	| regex result |
	
	regex := ICURegularExpression forString: 'b+'.

	regex setText: 'aabbccbbqq'.
	self assert: regex findNext.
	self assert: regex group = 'bb'.
	self assert: regex findNext.
	self assert: regex group = 'bb'.
	self deny: regex findNext.

	regex close! !

!ICURegularExpressionTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/30/2012 23:38'!
testNewInstance

	| regex |
	
	regex := ICURegularExpression forString: 'b+'.

	regex setText: 'bbbbbbb'.
	self assert: regex matches.

	regex setText: 'qqqqqqqqqqq'.
	self assert: regex matches not.

	regex close! !

!ICURegularExpressionTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/31/2012 21:21'!
testStringMatchesDo

	| result |

	result := OrderedCollection new.
	'aabbcc' icuRegex: 'b+' matchesDo: [ :each | result add: each ].
	self assert: result size = 1.
	self assert: result first = 'bb'! !

!ICURegularExpressionTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/31/2012 21:33'!
testStringMatchesRegex

	self assert: ('ab' icuMatchesRegex: 'a*b').		 		
	self assert: ('aaaaab' icuMatchesRegex: 'a*b').	
	self assert: ('b' icuMatchesRegex: 'a*b').	 	
	self deny: ('aac' icuMatchesRegex: 'a*b').
	
	self assert: ('0' icuMatchesRegex: '[0-9]').	
	self assert: ('9' icuMatchesRegex: '[0-9]').	
	self deny: ('a' icuMatchesRegex: '[0-9]').
	self deny: ('01' icuMatchesRegex: '[0-9]').	
	self assert: ('01442128629839374565' icuMatchesRegex: '[0-9]+').	
		! !

TestCase subclass: #ITwoByteStringTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/30/2012 11:38'!
testAsTwoByteString

	| string |
	
	string := 'Jan' asTwoByteString.
		
	self assert: string isTwoByteString.
	self assert: string size = 3.
	self assert: string printString = 'Jan' printString.
	
	self assert: string asTwoByteString == string! !

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/30/2012 11:31'!
testAsUTF16Bytes

	| string expected |
	
	string := 'Jan' asTwoByteString.
	
	expected := Smalltalk isLittleEndian
		ifTrue: [ #[ 74 0 97 0 110 0 ] ]
		ifFalse: [ #[ 0 74 0 97 0 110 ] ].
		
	self assert: expected = string asUTF16Bytes! !

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 15:04'!
testEquals

	| string |
	
	string := TwoByteString new: 3.
	string
		at: 1 put: $J ;
		at: 2 put: $a ;
		at: 3 put: $n.
		
	self assert: string = 'Jan'.
	self assert: 'Jan' = string.
	self assert: string hash = 'Jan' hash! !

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 2/21/2012 22:07'!
testNewString

	| string |
	
	string := TwoByteString new: 3.
	string
		at: 1 put: $J ;
		at: 2 put: $a ;
		at: 3 put: $n.
		
	self assert: string size = 3.
	self assert: string first = $J.
	self assert: string last = $n.
	self assert: string printString = 'Jan' printString! !

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 8/30/2012 11:39'!
testWideStringAsTwoByteString

	| string |
	
	string := 'Jan' asWideString asTwoByteString.
		
	self assert: string isTwoByteString.
	self assert: string size = 3.
	self assert: string printString = 'Jan' printString.
	
	self assert: string asTwoByteString == string! !
